==> igniteui-react-charts-16.6.4.tgz: package/ES5/igr-annotation-layer.js <==
import * as tslib_1 from "tslib";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
var IgrAnnotationLayer = /** @class */ (function (_super) {
    tslib_1.__extends(IgrAnnotationLayer, _super);
    function IgrAnnotationLayer(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrAnnotationLayer.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useIndex", {
        /**
         * Gets or sets whether this series should take up an index for auto brush coloring.
        */
        get: function () {
            return this.i.lz;
        },
        set: function (v) {
            this.i.lz = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useLegend", {
        /**
         * Gets or sets whether this series interacts with the chart legend.
        */
        get: function () {
            return this.i.l0;
        },
        set: function (v) {
            this.i.l0 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "cursorPosition", {
        /**
         * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
         * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
        */
        get: function () {
            return fromPoint(this.i.mr);
        },
        set: function (v) {
            this.i.mr = toPoint(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairDisabled", {
        /**
         * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
        */
        get: function () {
            return this.i.lw;
        },
        set: function (v) {
            this.i.lw = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairBehaviorDisabled", {
        /**
         * Gets whether or not the default crosshair behavior is disabled.
        */
        get: function () {
            return this.i.cm;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isIndexed", {
        /**
         * Gets if the series uses an index, which can be used to auto-assign it a color.
        */
        get: function () {
            return this.i.cw;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isUsableInLegend", {
        /**
         * Gets if the series should appear in any legends.
        */
        get: function () {
            return this.i.isUsableInLegend;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isAnnotationLayer", {
        /**
         * Gets whether this series is an annotation layer.
        */
        get: function () {
            return this.i.cj;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shouldRenderAsOverlay", {
        /**
         * Gets or sets whether this layer renders as an overlay or not.
        */
        get: function () {
            return this.i.ly;
        },
        set: function (v) {
            this.i.ly = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    return IgrAnnotationLayer;
}(IgrSeries));
export { IgrAnnotationLayer };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-annotation-layer.js <==
import * as tslib_1 from "tslib";
import { IgrSeries } from "./igr-series";
import { ensureBool, fromPoint, toPoint } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents the base class for annotation layer types. Annotations will usually disable some of the default hover/touch behaviors of the chart when they are introduced to the series collection.
 * In return they provide some valuable information as the cursor is moved by hovering over the chart, or performing a press-hold-drag interaction in touch mode.
*/
var IgrAnnotationLayer = /** @class */ (function (_super) {
    tslib_1.__extends(IgrAnnotationLayer, _super);
    function IgrAnnotationLayer(props) {
        return _super.call(this, props) || this;
    }
    Object.defineProperty(IgrAnnotationLayer.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useIndex", {
        /**
         * Gets or sets whether this series should take up an index for auto brush coloring.
        */
        get: function () {
            return this.i.l1;
        },
        set: function (v) {
            this.i.l1 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "useLegend", {
        /**
         * Gets or sets whether this series interacts with the chart legend.
        */
        get: function () {
            return this.i.l2;
        },
        set: function (v) {
            this.i.l2 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "cursorPosition", {
        /**
         * Gets or sets the world position to use instead of the pointer position for this annotation layer. If you set this value, rather than responding to the pointer, this layer will be fixed on the provided world position.
         * A world position has x and y values that range from 0 to 1 that represent the global position of the cursor relative to the entire ranges of the axes. The default of (NaN, NaN) means that the layer should react to pointer movement.
        */
        get: function () {
            return fromPoint(this.i.mt);
        },
        set: function (v) {
            this.i.mt = toPoint(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairDisabled", {
        /**
         * Gets or sets whether the series viewer's default crosshair should be disabled by the presence of this layer.
        */
        get: function () {
            return this.i.ly;
        },
        set: function (v) {
            this.i.ly = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isDefaultCrosshairBehaviorDisabled", {
        /**
         * Gets whether or not the default crosshair behavior is disabled.
        */
        get: function () {
            return this.i.cm;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isIndexed", {
        /**
         * Gets if the series uses an index, which can be used to auto-assign it a color.
        */
        get: function () {
            return this.i.cw;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isUsableInLegend", {
        /**
         * Gets if the series should appear in any legends.
        */
        get: function () {
            return this.i.isUsableInLegend;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "isAnnotationLayer", {
        /**
         * Gets whether this series is an annotation layer.
        */
        get: function () {
            return this.i.cj;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrAnnotationLayer.prototype, "shouldRenderAsOverlay", {
        /**
         * Gets or sets whether this layer renders as an overlay or not.
        */
        get: function () {
            return this.i.l0;
        },
        set: function (v) {
            this.i.l0 = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    return IgrAnnotationLayer;
}(IgrSeries));
export { IgrAnnotationLayer };
